@@ -10,7 +10,7 @@ from ..utils import support
 __all__ = ['odps_download_with_sql']
 
 
-def odps_download_with_sql(sql, save_path, connect=None, sep=',', tocache: bool = False):
+def odps_download_with_sql(sql, save_path, connect=None, sep=',', tocache: bool = False, hints: dict = None):
     """通过SQL下载全量数据"""
     connect = connect or support.odps_connect()
     save_path = os.path.join(tocache and env.CACHE_PROJECT_HOME or env.PROJECT_HOME, save_path)
@@ -19,7 +19,8 @@ def odps_download_with_sql(sql, save_path, connect=None, sep=',', tocache: bool
             fsql = f.read()
     else:
         fsql = sql
-    with connect.execute_sql(fsql).open_reader(tunnel=support.ODPS_TUNNEL, limit=support.ODPS_LIMIT) as reader:
+    with connect.execute_sql(fsql, hints=hints).open_reader(tunnel=support.ODPS_TUNNEL,
+                                                            limit=support.ODPS_LIMIT) as reader:
         headers = reader.schema.names
         with open(save_path, 'w', encoding='utf8') as writefile:
             csv_writer = csv.writer(writefile, delimiter=sep)
